searchData={"items":[{"type":"module","title":"Escape","doc":"Functionality to render ANSI escape sequences.\n\nThis module is quite similar to the Elixir module `IO.ANSI`. For more info\nabout [ANSI escape sequences](https://en.wikipedia.org/wiki/ANSI_escape_code),\nsee the `IO.ANSI` documentation.\n\nFor example, the function `IO.ANSI.format/1` and `Escape.format/1` working in\nthe same way.\n\n    iex> iodata = IO.ANSI.format([:green, \"hello\"])\n    [[[[] | \"\u001B[32m\"], \"hello\"] | \"\u001B[0m\"]\n    iex> iodata == Escape.format([:green, \"hello\"])\n    true\n\nThe `Escape` module adds the option `:theme` to `Escape.format/2`.\n\n    iex> Escape.format([:say, \"hello\"], theme: %{say: :green})\n    [[[[] | \"\u001B[32m\"], \"hello\"] | \"\u001B[0m\"]\n\nIn the theme are ANSI escape sequeneces allowed.\n\n    iex> Escape.format([:say, \"hello\"], theme: %{\n    ...>   orange: IO.ANSI.color(178),\n    ...>   say: :orange\n    ...> })\n    [[[[] | \"\u001B[38;5;178m\"], \"hello\"] | \"\u001B[0m\"]\n\nThe theme can also contain further fromats.\n\n    iex> theme = %{\n    ...>   orange: IO.ANSI.color(5, 3, 0),\n    ...>   gray_background: IO.ANSI.color_background(59),\n    ...>   say: [:orange, :gray_background],\n    ...>   blank: \" \"\n    ...> }\n    iex> Escape.format([:say, :blank, \"hello\", :blank], theme: theme)\n    [[[[[[], [[] | \"\u001B[38;5;214m\"] | \"\u001B[48;5;59m\"] | \" \"], \"hello\"] | \" \"] | \"\u001B[0m\"]\n    iex> Escape.format([:say, :blank, \"hello\", :blank], theme: theme, emit: false)\n    [[], \"hello\"]\n\nSee `Escape.format/2` for more info.","ref":"Escape.html"},{"type":"function","title":"Escape.colorizer/1","doc":"Returns a function that accepts a string and a named sequence and returns\niodata with the applied format.\n\nAccepts the same options as `format/2`.","ref":"Escape.html#colorizer/1"},{"type":"function","title":"Examples - Escape.colorizer/1","doc":"iex> colorizer = Escape.colorizer(theme: %{say: :green})\n    iex> colorizer.(\"hello\", :say)\n    [[[[] | \"\u001B[32m\"], \"hello\"] | \"\u001B[0m\"]","ref":"Escape.html#colorizer/1-examples"},{"type":"function","title":"Escape.format/2","doc":"Formats a chardata-like argument by converting named sequences into ANSI\nsequences.\n\nThe named sequences are represented by atoms. The named sequences can be\nextended by a map for the option `:theme`.\n\nIt will also append an `IO.ANSI.reset/0` to the chardata when a conversion is\nperformed. If you don't want this behaviour, use the option `reset?: false`.\n\nThe option `:emit` can be passed to enable or disable emitting ANSI codes.\nWhen false, no ANSI codes will be emitted. This option defaults to the return\nvalue of `IO.ANSI.enabled?/0`.","ref":"Escape.html#format/2"},{"type":"function","title":"Options - Escape.format/2","doc":"* `:theme` a map that adds ANSI codes usable in the Chardata-like argument.\n             The searching in the theme performs a deep search.\n\n  * `:reset` append an `IO.ANSI.reset/0` when true.\n\n  * `:emit` enables or disables emitting ANSI codes.","ref":"Escape.html#format/2-options"},{"type":"function","title":"Examples - Escape.format/2","doc":"iex> theme = %{\n    ...>   gainsboro: ANSI.color(4, 4, 4),\n    ...>   orange: ANSI.color(5, 3, 0),\n    ...>   aquamarine: ANSI.color(2, 5, 4),\n    ...>   error: :red,\n    ...>   debug: :orange,\n    ...>   info: :gainsboro\n    ...> }\n    iex> Escape.format([:error, \"error\"], theme: theme)\n    [[[[] | \"\u001B[31m\"], \"error\"] | \"\u001B[0m\"]\n    iex> Escape.format([:info, \"info\"], theme: theme)\n    [[[[] | \"\u001B[38;5;188m\"], \"info\"] | \"\u001B[0m\"]\n    iex> Escape.format([:info, \"info\"], theme: theme, reset: false)\n    [[[] | \"\u001B[38;5;188m\"], \"info\"]\n    iex> Escape.format([:info, \"info\"], theme: theme, emit: false)\n    [[], \"info\"]","ref":"Escape.html#format/2-examples"},{"type":"function","title":"Escape.formatter/1","doc":"Returns a function that accepts a chardata-like argument and applies\n`Escape.format/2` with the argument and the given `opts`.","ref":"Escape.html#formatter/1"},{"type":"function","title":"Examples - Escape.formatter/1","doc":"iex> formatter = Escape.formatter(theme: %{say: :green})\n    iex> formatter.([:say, \"hello\"])\n    [[[[] | \"\u001B[32m\"], \"hello\"] | \"\u001B[0m\"]","ref":"Escape.html#formatter/1-examples"},{"type":"function","title":"Escape.puts/2","doc":"Writes `ansidata` to a `device`, similar to `write/2`, but adds a newline at\nthe end.\n\nThe device is passed to the function with the option `:device` in the opts and\ndefaults to standard output.\n\nThe function also accepts the same options as `Escape.format/2`.","ref":"Escape.html#puts/2"},{"type":"function","title":"Escape.sequence/1","doc":"Formats a named ANSI sequences into an ANSI sequence.\n\nThe named sequences are represented by atoms.","ref":"Escape.html#sequence/1"},{"type":"function","title":"Examples - Escape.sequence/1","doc":"iex> Escape.sequence(:reverse)\n    \"\u001B[7m\"","ref":"Escape.html#sequence/1-examples"},{"type":"function","title":"Escape.sequences/0","doc":"Returns a list of all available named ANSI sequences.","ref":"Escape.html#sequences/0"},{"type":"function","title":"Escape.write/2","doc":"Writes `ansidata` to a device.\n\nThe device is passed to the function with the option `:device` in the opts and\ndefaults to standard output.\n\nThe function also accepts the same options as `Escape.format/2`.","ref":"Escape.html#write/2"},{"type":"type","title":"Escape.ansicode/0","doc":"","ref":"Escape.html#t:ansicode/0"},{"type":"type","title":"Escape.ansidata/0","doc":"","ref":"Escape.html#t:ansidata/0"},{"type":"type","title":"Escape.ansilist/0","doc":"","ref":"Escape.html#t:ansilist/0"}],"content_type":"text/markdown"}